// Copyright 2020 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This code was autogenerated. Do not edit directly.

// Code generated by client-gen. DO NOT EDIT.

package fake

import (
	"context"

	agonesv1 "agones.dev/agones/pkg/apis/agones/v1"
	autoscalingv1 "k8s.io/api/autoscaling/v1"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	labels "k8s.io/apimachinery/pkg/labels"
	schema "k8s.io/apimachinery/pkg/runtime/schema"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	testing "k8s.io/client-go/testing"
)

// FakeFleets implements FleetInterface
type FakeFleets struct {
	Fake *FakeAgonesV1
	ns   string
}

var fleetsResource = schema.GroupVersionResource{Group: "agones.dev", Version: "v1", Resource: "fleets"}

var fleetsKind = schema.GroupVersionKind{Group: "agones.dev", Version: "v1", Kind: "Fleet"}

// Get takes name of the fleet, and returns the corresponding fleet object, and an error if there is any.
func (c *FakeFleets) Get(ctx context.Context, name string, options v1.GetOptions) (result *agonesv1.Fleet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewGetAction(fleetsResource, c.ns, name), &agonesv1.Fleet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.Fleet), err
}

// List takes label and field selectors, and returns the list of Fleets that match those selectors.
func (c *FakeFleets) List(ctx context.Context, opts v1.ListOptions) (result *agonesv1.FleetList, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewListAction(fleetsResource, fleetsKind, c.ns, opts), &agonesv1.FleetList{})

	if obj == nil {
		return nil, err
	}

	label, _, _ := testing.ExtractFromListOptions(opts)
	if label == nil {
		label = labels.Everything()
	}
	list := &agonesv1.FleetList{ListMeta: obj.(*agonesv1.FleetList).ListMeta}
	for _, item := range obj.(*agonesv1.FleetList).Items {
		if label.Matches(labels.Set(item.Labels)) {
			list.Items = append(list.Items, item)
		}
	}
	return list, err
}

// Watch returns a watch.Interface that watches the requested fleets.
func (c *FakeFleets) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	return c.Fake.
		InvokesWatch(testing.NewWatchAction(fleetsResource, c.ns, opts))

}

// Create takes the representation of a fleet and creates it.  Returns the server's representation of the fleet, and an error, if there is any.
func (c *FakeFleets) Create(ctx context.Context, fleet *agonesv1.Fleet, opts v1.CreateOptions) (result *agonesv1.Fleet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewCreateAction(fleetsResource, c.ns, fleet), &agonesv1.Fleet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.Fleet), err
}

// Update takes the representation of a fleet and updates it. Returns the server's representation of the fleet, and an error, if there is any.
func (c *FakeFleets) Update(ctx context.Context, fleet *agonesv1.Fleet, opts v1.UpdateOptions) (result *agonesv1.Fleet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateAction(fleetsResource, c.ns, fleet), &agonesv1.Fleet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.Fleet), err
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *FakeFleets) UpdateStatus(ctx context.Context, fleet *agonesv1.Fleet, opts v1.UpdateOptions) (*agonesv1.Fleet, error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceAction(fleetsResource, "status", c.ns, fleet), &agonesv1.Fleet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.Fleet), err
}

// Delete takes name of the fleet and deletes it. Returns an error if one occurs.
func (c *FakeFleets) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	_, err := c.Fake.
		Invokes(testing.NewDeleteAction(fleetsResource, c.ns, name), &agonesv1.Fleet{})

	return err
}

// DeleteCollection deletes a collection of objects.
func (c *FakeFleets) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	action := testing.NewDeleteCollectionAction(fleetsResource, c.ns, listOpts)

	_, err := c.Fake.Invokes(action, &agonesv1.FleetList{})
	return err
}

// Patch applies the patch and returns the patched fleet.
func (c *FakeFleets) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *agonesv1.Fleet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceAction(fleetsResource, c.ns, name, pt, data, subresources...), &agonesv1.Fleet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.Fleet), err
}

// GetScale takes name of the fleet, and returns the corresponding scale object, and an error if there is any.
func (c *FakeFleets) GetScale(ctx context.Context, fleetName string, options v1.GetOptions) (result *autoscalingv1.Scale, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewGetSubresourceAction(fleetsResource, c.ns, "scale", fleetName), &autoscalingv1.Scale{})

	if obj == nil {
		return nil, err
	}
	return obj.(*autoscalingv1.Scale), err
}

// UpdateScale takes the representation of a scale and updates it. Returns the server's representation of the scale, and an error, if there is any.
func (c *FakeFleets) UpdateScale(ctx context.Context, fleetName string, scale *autoscalingv1.Scale, opts v1.UpdateOptions) (result *autoscalingv1.Scale, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceAction(fleetsResource, "scale", c.ns, scale), &autoscalingv1.Scale{})

	if obj == nil {
		return nil, err
	}
	return obj.(*autoscalingv1.Scale), err
}
